FrameContext

Struct FrameContext 

pub struct FrameContext<'a> {
    pub device: &'a Device,
    pub queue: &'a Queue,
    pub config: &'a SurfaceConfiguration,
}
Provides context for operations that occur once per frame.

This struct bundles essential WGPU resources and configuration that are relevant for the entire rendering frame, but are not specific to a single render pass.

Fields

device: &'a Device

The WGPU device.

queue: &'a Queue

The WGPU queue.

config: &'a SurfaceConfiguration

The current surface configuration.